==> libosmo-netif_0.1.1.orig.tar.xz: libosmo-netif-0.1.1/README.md <==
libosmo-netif- Osmocom network interface interface library
==========================================================

This repository contains a C-language library that form the
basis of various higher-layer cellular communications protocol
implementation.  It implements stream server and clients for TCP, UDP,
IPA as well as the non-standard/proprietary OSMUX protocol.

Homepage
--------

The official homepage of the project is
<https://osmocom.org/projects/libosmo-netif>

GIT Repository
--------------

You can clone from the official libosmo-netif.git repository using

	git clone git://git.osmocom.org/libosmo-netif.git

There is a cgit interface at <http://git.osmocom.org/libosmo-netif/>

Documentation
-------------

There is no Doxygen-generated API documentation yet for this library. It
would be great to some day have it, comparable to libosmocore.

Mailing List
------------

Discussions related to libosmo-netif are happening on the
openbsc@lists.osmocom.org mailing list, please see
<https://lists.osmocom.org/mailman/listinfo/openbsc> for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
<https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards>

We us a gerrit based patch submission/review process for managing
contributions.  Please see
<https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit> for
more details

The current patch queue for libosmo-netif can be seen at
<https://gerrit.osmocom.org/#/q/project:libosmo-netif+status:open>

==> libosmo-netif_1.6.0.orig.tar.xz: libosmo-netif-1.6.0/README.md <==
libosmo-netif- Osmocom network interface library
==========================================================

This repository contains a C-language library that form the
basis of various higher-layer cellular communications protocol
implementation.  It implements stream server and clients for TCP, UDP,
IPA as well as the non-standard/proprietary OSMUX protocol.

Homepage
--------

The official homepage of the project is
<https://osmocom.org/projects/libosmo-netif>

GIT Repository
--------------

You can clone from the official libosmo-netif.git repository using

	git clone https://gitea.osmocom.org/osmocom/libosmo-netif

There is a web interface at <https://gitea.osmocom.org/osmocom/libosmo-netif>

Documentation
-------------

There is no Doxygen-generated API documentation yet for this library. It
would be great to some day have it, comparable to libosmocore.

Mailing List
------------

Discussions related to libosmo-netif are happening on the
openbsc@lists.osmocom.org mailing list, please see
<https://lists.osmocom.org/mailman/listinfo/openbsc> for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
<https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards>

We use a Gerrit based patch submission/review process for managing
contributions.  Please see
<https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit> for
more details

The current patch queue for libosmo-netif can be seen at
<https://gerrit.osmocom.org/#/q/project:libosmo-netif+status:open>
